@@ -1,4 +1,6 @@
 """Demo light platform that implements lights."""
+from __future__ import annotations
+
 import random
 
 from homeassistant.components.light import (
@@ -6,12 +8,13 @@ from homeassistant.components.light import (
     ATTR_COLOR_TEMP,
     ATTR_EFFECT,
     ATTR_HS_COLOR,
-    ATTR_WHITE_VALUE,
-    SUPPORT_BRIGHTNESS,
-    SUPPORT_COLOR,
-    SUPPORT_COLOR_TEMP,
+    ATTR_RGBW_COLOR,
+    ATTR_RGBWW_COLOR,
+    COLOR_MODE_COLOR_TEMP,
+    COLOR_MODE_HS,
+    COLOR_MODE_RGBW,
+    COLOR_MODE_RGBWW,
     SUPPORT_EFFECT,
-    SUPPORT_WHITE_VALUE,
     LightEntity,
 )
 
@@ -23,13 +26,7 @@ LIGHT_EFFECT_LIST = ["rainbow", "none"]
 
 LIGHT_TEMPS = [240, 380]
 
-SUPPORT_DEMO = (
-    SUPPORT_BRIGHTNESS
-    | SUPPORT_COLOR_TEMP
-    | SUPPORT_EFFECT
-    | SUPPORT_COLOR
-    | SUPPORT_WHITE_VALUE
-)
+SUPPORT_DEMO = {COLOR_MODE_HS, COLOR_MODE_COLOR_TEMP}
 
 
 async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
@@ -37,16 +34,43 @@ async def async_setup_platform(hass, config, async_add_entities, discovery_info=
     async_add_entities(
         [
             DemoLight(
-                "light_1",
-                "Bed Light",
-                False,
-                True,
+                available=True,
                 effect_list=LIGHT_EFFECT_LIST,
                 effect=LIGHT_EFFECT_LIST[0],
+                name="Bed Light",
+                state=False,
+                unique_id="light_1",
             ),
-            DemoLight("light_2", "Ceiling Lights", True, True, ct=LIGHT_TEMPS[1]),
             DemoLight(
-                "light_3", "Kitchen Lights", True, True, LIGHT_COLORS[1], LIGHT_TEMPS[0]
+                available=True,
+                ct=LIGHT_TEMPS[1],
+                name="Ceiling Lights",
+                state=True,
+                unique_id="light_2",
+            ),
+            DemoLight(
+                available=True,
+                hs_color=LIGHT_COLORS[1],
+                name="Kitchen Lights",
+                state=True,
+                unique_id="light_3",
+            ),
+            DemoLight(
+                available=True,
+                ct=LIGHT_TEMPS[1],
+                name="Office RGBW Lights",
+                rgbw_color=(255, 0, 0, 255),
+                state=True,
+                supported_color_modes={COLOR_MODE_RGBW},
+                unique_id="light_4",
+            ),
+            DemoLight(
+                available=True,
+                name="Living Room RGBWW Lights",
+                rgbww_color=(255, 0, 0, 255, 0),
+                state=True,
+                supported_color_modes={COLOR_MODE_RGBWW},
+                unique_id="light_5",
             ),
         ]
     )
@@ -66,25 +90,41 @@ class DemoLight(LightEntity):
         name,
         state,
         available=False,
-        hs_color=None,
-        ct=None,
         brightness=180,
-        white=200,
+        ct=None,
         effect_list=None,
         effect=None,
+        hs_color=None,
+        rgbw_color=None,
+        rgbww_color=None,
+        supported_color_modes=None,
     ):
         """Initialize the light."""
-        self._unique_id = unique_id
-        self._name = name
-        self._state = state
-        self._hs_color = hs_color
-        self._ct = ct or random.choice(LIGHT_TEMPS)
-        self._brightness = brightness
-        self._white = white
-        self._effect_list = effect_list
-        self._effect = effect
         self._available = True
-        self._color_mode = "ct" if ct is not None and hs_color is None else "hs"
+        self._brightness = brightness
+        self._ct = ct or random.choice(LIGHT_TEMPS)
+        self._effect = effect
+        self._effect_list = effect_list
+        self._features = 0
+        self._hs_color = hs_color
+        self._name = name
+        self._rgbw_color = rgbw_color
+        self._rgbww_color = rgbww_color
+        self._state = state
+        self._unique_id = unique_id
+        if hs_color:
+            self._color_mode = COLOR_MODE_HS
+        elif rgbw_color:
+            self._color_mode = COLOR_MODE_RGBW
+        elif rgbww_color:
+            self._color_mode = COLOR_MODE_RGBWW
+        else:
+            self._color_mode = COLOR_MODE_COLOR_TEMP
+        if not supported_color_modes:
+            supported_color_modes = SUPPORT_DEMO
+        self._color_modes = supported_color_modes
+        if self._effect_list is not None:
+            self._features |= SUPPORT_EFFECT
 
     @property
     def device_info(self):
@@ -124,24 +164,30 @@ class DemoLight(LightEntity):
         """Return the brightness of this light between 0..255."""
         return self._brightness
 
+    @property
+    def color_mode(self) -> str | None:
+        """Return the color mode of the light."""
+        return self._color_mode
+
     @property
     def hs_color(self) -> tuple:
         """Return the hs color value."""
-        if self._color_mode == "hs":
-            return self._hs_color
-        return None
+        return self._hs_color
+
+    @property
+    def rgbw_color(self) -> tuple:
+        """Return the rgbw color value."""
+        return self._rgbw_color
+
+    @property
+    def rgbww_color(self) -> tuple:
+        """Return the rgbww color value."""
+        return self._rgbww_color
 
     @property
     def color_temp(self) -> int:
         """Return the CT color temperature."""
-        if self._color_mode == "ct":
-            return self._ct
-        return None
-
-    @property
-    def white_value(self) -> int:
-        """Return the white value of this light between 0..255."""
-        return self._white
+        return self._ct
 
     @property
     def effect_list(self) -> list:
@@ -161,26 +207,36 @@ class DemoLight(LightEntity):
     @property
     def supported_features(self) -> int:
         """Flag supported features."""
-        return SUPPORT_DEMO
+        return self._features
+
+    @property
+    def supported_color_modes(self) -> set | None:
+        """Flag supported color modes."""
+        return self._color_modes
 
     async def async_turn_on(self, **kwargs) -> None:
         """Turn the light on."""
         self._state = True
 
+        if ATTR_RGBW_COLOR in kwargs:
+            self._color_mode = COLOR_MODE_RGBW
+            self._rgbw_color = kwargs[ATTR_RGBW_COLOR]
+
+        if ATTR_RGBWW_COLOR in kwargs:
+            self._color_mode = COLOR_MODE_RGBWW
+            self._rgbww_color = kwargs[ATTR_RGBWW_COLOR]
+
         if ATTR_HS_COLOR in kwargs:
-            self._color_mode = "hs"
+            self._color_mode = COLOR_MODE_HS
             self._hs_color = kwargs[ATTR_HS_COLOR]
 
         if ATTR_COLOR_TEMP in kwargs:
-            self._color_mode = "ct"
+            self._color_mode = COLOR_MODE_COLOR_TEMP
             self._ct = kwargs[ATTR_COLOR_TEMP]
 
         if ATTR_BRIGHTNESS in kwargs:
             self._brightness = kwargs[ATTR_BRIGHTNESS]
 
-        if ATTR_WHITE_VALUE in kwargs:
-            self._white = kwargs[ATTR_WHITE_VALUE]
-
         if ATTR_EFFECT in kwargs:
             self._effect = kwargs[ATTR_EFFECT]
 
