@@ -1,8 +1,9 @@
 """The Internet Printing Protocol (IPP) integration."""
-import asyncio
+from __future__ import annotations
+
 from datetime import timedelta
 import logging
-from typing import Any, Dict
+from typing import Any
 
 from pyipp import IPP, IPPError, Printer as IPPPrinter
 
@@ -16,10 +17,12 @@ from homeassistant.const import (
     CONF_VERIFY_SSL,
 )
 from homeassistant.core import HomeAssistant
-from homeassistant.exceptions import ConfigEntryNotReady
 from homeassistant.helpers.aiohttp_client import async_get_clientsession
-from homeassistant.helpers.entity import Entity
-from homeassistant.helpers.update_coordinator import DataUpdateCoordinator, UpdateFailed
+from homeassistant.helpers.update_coordinator import (
+    CoordinatorEntity,
+    DataUpdateCoordinator,
+    UpdateFailed,
+)
 
 from .const import (
     ATTR_IDENTIFIERS,
@@ -36,57 +39,38 @@ SCAN_INTERVAL = timedelta(seconds=60)
 _LOGGER = logging.getLogger(__name__)
 
 
-async def async_setup(hass: HomeAssistant, config: Dict) -> bool:
-    """Set up the IPP component."""
-    hass.data.setdefault(DOMAIN, {})
-    return True
-
-
 async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Set up IPP from a config entry."""
-
-    # Create IPP instance for this entry
-    coordinator = IPPDataUpdateCoordinator(
-        hass,
-        host=entry.data[CONF_HOST],
-        port=entry.data[CONF_PORT],
-        base_path=entry.data[CONF_BASE_PATH],
-        tls=entry.data[CONF_SSL],
-        verify_ssl=entry.data[CONF_VERIFY_SSL],
-    )
-    await coordinator.async_refresh()
-
-    if not coordinator.last_update_success:
-        raise ConfigEntryNotReady
-
-    hass.data[DOMAIN][entry.entry_id] = coordinator
-
-    for component in PLATFORMS:
-        hass.async_create_task(
-            hass.config_entries.async_forward_entry_setup(entry, component)
+    hass.data.setdefault(DOMAIN, {})
+    coordinator = hass.data[DOMAIN].get(entry.entry_id)
+    if not coordinator:
+        # Create IPP instance for this entry
+        coordinator = IPPDataUpdateCoordinator(
+            hass,
+            host=entry.data[CONF_HOST],
+            port=entry.data[CONF_PORT],
+            base_path=entry.data[CONF_BASE_PATH],
+            tls=entry.data[CONF_SSL],
+            verify_ssl=entry.data[CONF_VERIFY_SSL],
         )
+        hass.data[DOMAIN][entry.entry_id] = coordinator
+
+    await coordinator.async_config_entry_first_refresh()
+
+    hass.config_entries.async_setup_platforms(entry, PLATFORMS)
 
     return True
 
 
 async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Unload a config entry."""
-    unload_ok = all(
-        await asyncio.gather(
-            *[
-                hass.config_entries.async_forward_entry_unload(entry, component)
-                for component in PLATFORMS
-            ]
-        )
-    )
-
+    unload_ok = await hass.config_entries.async_unload_platforms(entry, PLATFORMS)
     if unload_ok:
         hass.data[DOMAIN].pop(entry.entry_id)
-
     return unload_ok
 
 
-class IPPDataUpdateCoordinator(DataUpdateCoordinator):
+class IPPDataUpdateCoordinator(DataUpdateCoordinator[IPPPrinter]):
     """Class to manage fetching IPP data from single endpoint."""
 
     def __init__(
@@ -110,7 +94,10 @@ class IPPDataUpdateCoordinator(DataUpdateCoordinator):
         )
 
         super().__init__(
-            hass, _LOGGER, name=DOMAIN, update_interval=SCAN_INTERVAL,
+            hass,
+            _LOGGER,
+            name=DOMAIN,
+            update_interval=SCAN_INTERVAL,
         )
 
     async def _async_update_data(self) -> IPPPrinter:
@@ -118,28 +105,29 @@ class IPPDataUpdateCoordinator(DataUpdateCoordinator):
         try:
             return await self.ipp.printer()
         except IPPError as error:
-            raise UpdateFailed(f"Invalid response from API: {error}")
+            raise UpdateFailed(f"Invalid response from API: {error}") from error
 
 
-class IPPEntity(Entity):
+class IPPEntity(CoordinatorEntity):
     """Defines a base IPP entity."""
 
     def __init__(
         self,
         *,
         entry_id: str,
+        device_id: str,
         coordinator: IPPDataUpdateCoordinator,
         name: str,
         icon: str,
         enabled_default: bool = True,
     ) -> None:
         """Initialize the IPP entity."""
+        super().__init__(coordinator)
+        self._device_id = device_id
         self._enabled_default = enabled_default
         self._entry_id = entry_id
         self._icon = icon
         self._name = name
-        self._unsub_dispatcher = None
-        self.coordinator = coordinator
 
     @property
     def name(self) -> str:
@@ -151,38 +139,19 @@ class IPPEntity(Entity):
         """Return the mdi icon of the entity."""
         return self._icon
 
-    @property
-    def available(self) -> bool:
-        """Return True if entity is available."""
-        return self.coordinator.last_update_success
-
     @property
     def entity_registry_enabled_default(self) -> bool:
         """Return if the entity should be enabled when first added to the entity registry."""
         return self._enabled_default
 
     @property
-    def should_poll(self) -> bool:
-        """Return the polling requirement of the entity."""
-        return False
-
-    async def async_added_to_hass(self) -> None:
-        """Connect to dispatcher listening for entity data notifications."""
-        self.coordinator.async_add_listener(self.async_write_ha_state)
-
-    async def async_will_remove_from_hass(self) -> None:
-        """Disconnect from update signal."""
-        self.coordinator.async_remove_listener(self.async_write_ha_state)
-
-    async def async_update(self) -> None:
-        """Update an IPP entity."""
-        await self.coordinator.async_request_refresh()
-
-    @property
-    def device_info(self) -> Dict[str, Any]:
+    def device_info(self) -> dict[str, Any]:
         """Return device information about this IPP device."""
+        if self._device_id is None:
+            return None
+
         return {
-            ATTR_IDENTIFIERS: {(DOMAIN, self.coordinator.data.info.uuid)},
+            ATTR_IDENTIFIERS: {(DOMAIN, self._device_id)},
             ATTR_NAME: self.coordinator.data.info.name,
             ATTR_MANUFACTURER: self.coordinator.data.info.manufacturer,
             ATTR_MODEL: self.coordinator.data.info.model,
