@@ -1,7 +1,9 @@
 """Tesla Config Flow."""
 import logging
 
+import httpx
 from teslajsonpy import Controller as TeslaAPI, TeslaException
+from teslajsonpy.exceptions import IncompleteCredentials
 import voluptuous as vol
 
 from homeassistant import config_entries, core, exceptions
@@ -14,15 +16,17 @@ from homeassistant.const import (
     HTTP_UNAUTHORIZED,
 )
 from homeassistant.core import callback
-from homeassistant.helpers import aiohttp_client, config_validation as cv
+from homeassistant.helpers import config_validation as cv
+from homeassistant.helpers.httpx_client import SERVER_SOFTWARE, USER_AGENT
 
 from .const import (
+    CONF_EXPIRATION,
     CONF_WAKE_ON_START,
     DEFAULT_SCAN_INTERVAL,
     DEFAULT_WAKE_ON_START,
+    DOMAIN,
     MIN_SCAN_INTERVAL,
 )
-from .const import DOMAIN  # pylint:disable=unused-import
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -36,6 +40,7 @@ class TeslaConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
     def __init__(self):
         """Initialize the tesla flow."""
         self.username = None
+        self.reauth = False
 
     async def async_step_import(self, import_config):
         """Import a config entry from configuration.yaml."""
@@ -47,10 +52,7 @@ class TeslaConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
 
         if user_input is not None:
             existing_entry = self._async_entry_for_username(user_input[CONF_USERNAME])
-            if (
-                existing_entry
-                and existing_entry.data[CONF_PASSWORD] == user_input[CONF_PASSWORD]
-            ):
+            if existing_entry and not self.reauth:
                 return self.async_abort(reason="already_configured")
 
             try:
@@ -82,6 +84,7 @@ class TeslaConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
     async def async_step_reauth(self, data):
         """Handle configuration by re-auth."""
         self.username = data[CONF_USERNAME]
+        self.reauth = True
         return await self.async_step_user()
 
     @staticmethod
@@ -147,25 +150,32 @@ async def validate_input(hass: core.HomeAssistant, data):
     """
 
     config = {}
-    websession = aiohttp_client.async_get_clientsession(hass)
+    async_client = httpx.AsyncClient(headers={USER_AGENT: SERVER_SOFTWARE}, timeout=60)
+
     try:
         controller = TeslaAPI(
-            websession,
+            async_client,
             email=data[CONF_USERNAME],
             password=data[CONF_PASSWORD],
             update_interval=DEFAULT_SCAN_INTERVAL,
         )
-        (config[CONF_TOKEN], config[CONF_ACCESS_TOKEN]) = await controller.connect(
-            test_login=True
-        )
+        result = await controller.connect(test_login=True)
+        config[CONF_TOKEN] = result["refresh_token"]
+        config[CONF_ACCESS_TOKEN] = result["access_token"]
+        config[CONF_EXPIRATION] = result[CONF_EXPIRATION]
         config[CONF_USERNAME] = data[CONF_USERNAME]
         config[CONF_PASSWORD] = data[CONF_PASSWORD]
+    except IncompleteCredentials as ex:
+        _LOGGER.error("Authentication error: %s %s", ex.message, ex)
+        raise InvalidAuth() from ex
     except TeslaException as ex:
         if ex.code == HTTP_UNAUTHORIZED:
             _LOGGER.error("Invalid credentials: %s", ex)
             raise InvalidAuth() from ex
         _LOGGER.error("Unable to communicate with Tesla API: %s", ex)
         raise CannotConnect() from ex
+    finally:
+        await async_client.aclose()
     _LOGGER.debug("Credentials successfully connected to the Tesla API")
     return config
 
